aboutsummaryrefslogtreecommitdiffstats
path: root/target-sparc/translate.c
diff options
context:
space:
mode:
Diffstat (limited to 'target-sparc/translate.c')
-rw-r--r--target-sparc/translate.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/target-sparc/translate.c b/target-sparc/translate.c
index 8b988fb5c..2c07385d5 100644
--- a/target-sparc/translate.c
+++ b/target-sparc/translate.c
@@ -4932,12 +4932,12 @@ void gen_pc_load(CPUState *env, TranslationBlock *tb,
if (npc == 1) {
/* dynamic NPC: already stored */
} else if (npc == 2) {
- target_ulong t2 = (target_ulong)(unsigned long)puc;
- /* jump PC: use T2 and the jump targets of the translation */
- if (t2)
+ /* jump PC: use 'cond' and the jump targets of the translation */
+ if (env->cond) {
env->npc = gen_opc_jump_pc[0];
- else
+ } else {
env->npc = gen_opc_jump_pc[1];
+ }
} else {
env->npc = npc;
}